( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-lcircle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf b-circle.mf b-lcircle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-lcirclew.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf b-circlew.mf b-lcirclew.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-bbold.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-bbold.mf b-bbold.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-circle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-circle.mf b-circle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-circlew.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-circlew.mf b-circlew.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmb.mf b-cmb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbizx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbizx.mf b-cmbizx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbozx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbozx.mf b-cmbozx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbsy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbsy.mf b-cmbsy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbszx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbszx.mf b-cmbszx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbx.mf b-cmbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbxsl.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbxsl.mf b-cmbxsl.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbxti.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbxti.mf b-cmbxti.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbz.mf b-cmbz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmbzx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmbzx.mf b-cmbzx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmcsc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmcsc.mf b-cmcsc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmdszc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmdszc.mf b-cmdszc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmdunh.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmdunh.mf b-cmdunh.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmex.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmex.mf b-cmex.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmff.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmff.mf b-cmff.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmfi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmfi.mf b-cmfi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmfib.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmfib.mf b-cmfib.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cminch.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cminch.mf b-cminch.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmitt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmitt.mf b-cmitt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmmi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmmi.mf b-cmmi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmmib.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmmib.mf b-cmmib.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmr.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmr.mf b-cmr.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmrcz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmrcz.mf b-cmrcz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmrisz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmrisz.mf b-cmrisz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmritz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmritz.mf b-cmritz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmriz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmriz.mf b-cmriz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmrotz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmrotz.mf b-cmrotz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmroz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmroz.mf b-cmroz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmrsz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmrsz.mf b-cmrsz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmrtz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmrtz.mf b-cmrtz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmruz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmruz.mf b-cmruz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmrz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmrz.mf b-cmrz.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmsl.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmsl.mf b-cmsl.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmsltt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmsltt.mf b-cmsltt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmss.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmss.mf b-cmss.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmssbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmssbx.mf b-cmssbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmssdc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmssdc.mf b-cmssdc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmssi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmssi.mf b-cmssi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmssq.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmssq.mf b-cmssq.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmssqi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmssqi.mf b-cmssqi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmssxi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmssxi.mf b-cmssxi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmsy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmsy.mf b-cmsy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmtcsc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmtcsc.mf b-cmtcsc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmtex.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmtex.mf b-cmtex.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmti.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmti.mf b-cmti.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmtt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmtt.mf b-cmtt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmu.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmu.mf b-cmu.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cmvtt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cmvtt.mf b-cmvtt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-cspex.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-cspex.mf b-cspex.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-czinch.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-czinch.mf b-czinch.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-czssq.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-czssq.mf b-czssq.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-czssqi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-czssqi.mf b-czssqi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-lasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-lasy.mf b-lasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-lasyb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-lasyb.mf b-lasyb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-line.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-line.mf b-line.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-linew.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-linew.mf b-linew.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-wasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-wasy.mf b-wasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf b-wasyb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/b-wasyb.mf b-wasyb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-bmath.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-bmath.mf c-bmath.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-circle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-circle.mf c-circle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmbx.mf c-cmbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmff.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmff.mf c-cmff.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmmi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmmi.mf c-cmmi.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmr.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmr.mf c-cmr.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmss.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmss.mf c-cmss.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmssbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmssbx.mf c-cmssbx.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmssq.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmssq.mf c-cmssq.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmti.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmti.mf c-cmti.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-cmtt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-cmtt.mf c-cmtt.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-line.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-line.mf c-line.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf c-sigma.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/c-sigma.mf c-sigma.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf circle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/circle.mf circle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cyccsc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cyccsc.mf cyccsc.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cycoding.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cycoding.mf cycoding.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cyitall.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cyitall.mf cyitall.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cyrillic.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cyrillic.mf cyrillic.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cyrl.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cyrl.mf cyrl.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cyrsymb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cyrsymb.mf cyrsymb.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cyru.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cyru.mf cyru.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cytextit.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cytextit.mf cytextit.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf cytitle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/cytitle.mf cytitle.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf lasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/lasy.mf lasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf line.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/line.mf line.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; rm -rf wasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter/base/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/base/src/wasy.mf wasy.mf )
( cd usr/lib/texmf/fonts/cm/sauter ; rm -rf create.sh )
( cd usr/lib/texmf/fonts/cm/sauter ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/create.sh create.sh )
( cd usr/lib/texmf/fonts/cm/sauter ; rm -rf make-cyr )
( cd usr/lib/texmf/fonts/cm/sauter ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/make-cyr make-cyr )
( cd usr/lib/texmf/fonts/cm/sauter ; rm -rf make-latex-mf )
( cd usr/lib/texmf/fonts/cm/sauter ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/make-latex-mf make-latex-mf )
( cd usr/lib/texmf/fonts/cm/sauter ; rm -rf make-mf )
( cd usr/lib/texmf/fonts/cm/sauter ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/make-mf make-mf )
( cd usr/lib/texmf/fonts/cm/sauter/misc ; rm -rf ChangeLog )
( cd usr/lib/texmf/fonts/cm/sauter/misc ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/misc/ChangeLog ChangeLog )
( cd usr/lib/texmf/fonts/cm/sauter/misc ; rm -rf Description )
( cd usr/lib/texmf/fonts/cm/sauter/misc ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/misc/Description Description )
( cd usr/lib/texmf/fonts/cm/sauter/misc ; rm -rf ReadMe.2_0 )
( cd usr/lib/texmf/fonts/cm/sauter/misc ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/misc/ReadMe.2_0 ReadMe.2_0 )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb10.mf cmb10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb11.mf cmb11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb12.mf cmb12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb14.mf cmb14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb17.mf cmb17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb20.mf cmb20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb25.mf cmb25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb5.mf cmb5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb6.mf cmb6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb7.mf cmb7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb8.mf cmb8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmb9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmb9.mf cmb9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx10.mf cmbizx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx11.mf cmbizx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx12.mf cmbizx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx14.mf cmbizx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx17.mf cmbizx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx20.mf cmbizx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx25.mf cmbizx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx5.mf cmbizx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx6.mf cmbizx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx7.mf cmbizx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx8.mf cmbizx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbizx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbizx9.mf cmbizx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx10.mf cmbozx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx11.mf cmbozx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx12.mf cmbozx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx14.mf cmbozx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx17.mf cmbozx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx20.mf cmbozx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx25.mf cmbozx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx5.mf cmbozx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx6.mf cmbozx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx7.mf cmbozx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx8.mf cmbozx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbozx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbozx9.mf cmbozx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy10.mf cmbsy10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy11.mf cmbsy11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy12.mf cmbsy12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy14.mf cmbsy14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy17.mf cmbsy17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy20.mf cmbsy20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy25.mf cmbsy25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy5.mf cmbsy5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy6.mf cmbsy6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy7.mf cmbsy7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy8.mf cmbsy8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbsy9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbsy9.mf cmbsy9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx10.mf cmbszx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx11.mf cmbszx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx12.mf cmbszx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx14.mf cmbszx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx17.mf cmbszx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx20.mf cmbszx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx25.mf cmbszx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx5.mf cmbszx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx6.mf cmbszx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx7.mf cmbszx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx8.mf cmbszx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbszx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbszx9.mf cmbszx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx10.mf cmbx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx11.mf cmbx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx12.mf cmbx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx14.mf cmbx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx17.mf cmbx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx20.mf cmbx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx25.mf cmbx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx5.mf cmbx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx6.mf cmbx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx7.mf cmbx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx8.mf cmbx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbx9.mf cmbx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl10.mf cmbxsl10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl11.mf cmbxsl11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl12.mf cmbxsl12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl14.mf cmbxsl14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl17.mf cmbxsl17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl20.mf cmbxsl20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl25.mf cmbxsl25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl5.mf cmbxsl5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl6.mf cmbxsl6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl7.mf cmbxsl7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl8.mf cmbxsl8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxsl9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxsl9.mf cmbxsl9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti10.mf cmbxti10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti11.mf cmbxti11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti12.mf cmbxti12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti14.mf cmbxti14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti17.mf cmbxti17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti20.mf cmbxti20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti25.mf cmbxti25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti5.mf cmbxti5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti6.mf cmbxti6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti7.mf cmbxti7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti8.mf cmbxti8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbxti9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbxti9.mf cmbxti9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz10.mf cmbz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz11.mf cmbz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz12.mf cmbz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz14.mf cmbz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz17.mf cmbz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz20.mf cmbz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz25.mf cmbz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz5.mf cmbz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz6.mf cmbz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz7.mf cmbz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz8.mf cmbz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbz9.mf cmbz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx10.mf cmbzx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx11.mf cmbzx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx12.mf cmbzx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx14.mf cmbzx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx17.mf cmbzx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx20.mf cmbzx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx25.mf cmbzx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx5.mf cmbzx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx6.mf cmbzx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx7.mf cmbzx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx8.mf cmbzx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmbzx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmbzx9.mf cmbzx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc10.mf cmcsc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc11.mf cmcsc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc12.mf cmcsc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc14.mf cmcsc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc17.mf cmcsc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc20.mf cmcsc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc25.mf cmcsc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc5.mf cmcsc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc6.mf cmcsc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc7.mf cmcsc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc8.mf cmcsc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmcsc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmcsc9.mf cmcsc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc10.mf cmdszc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc11.mf cmdszc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc12.mf cmdszc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc14.mf cmdszc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc17.mf cmdszc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc20.mf cmdszc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc25.mf cmdszc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc5.mf cmdszc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc6.mf cmdszc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc7.mf cmdszc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc8.mf cmdszc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdszc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdszc9.mf cmdszc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh10.mf cmdunh10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh11.mf cmdunh11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh12.mf cmdunh12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh14.mf cmdunh14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh17.mf cmdunh17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh20.mf cmdunh20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh25.mf cmdunh25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh5.mf cmdunh5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh6.mf cmdunh6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh7.mf cmdunh7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh8.mf cmdunh8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmdunh9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmdunh9.mf cmdunh9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex10.mf cmex10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex11.mf cmex11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex12.mf cmex12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex14.mf cmex14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex17.mf cmex17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex20.mf cmex20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex25.mf cmex25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex5.mf cmex5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex6.mf cmex6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex7.mf cmex7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex8.mf cmex8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmex9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmex9.mf cmex9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff10.mf cmff10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff11.mf cmff11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff12.mf cmff12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff14.mf cmff14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff17.mf cmff17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff20.mf cmff20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff25.mf cmff25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff5.mf cmff5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff6.mf cmff6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff7.mf cmff7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff8.mf cmff8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmff9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmff9.mf cmff9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi10.mf cmfi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi11.mf cmfi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi12.mf cmfi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi14.mf cmfi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi17.mf cmfi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi20.mf cmfi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi25.mf cmfi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi5.mf cmfi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi6.mf cmfi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi7.mf cmfi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi8.mf cmfi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfi9.mf cmfi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib10.mf cmfib10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib11.mf cmfib11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib12.mf cmfib12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib14.mf cmfib14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib17.mf cmfib17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib20.mf cmfib20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib25.mf cmfib25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib5.mf cmfib5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib6.mf cmfib6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib7.mf cmfib7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib8.mf cmfib8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmfib9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmfib9.mf cmfib9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch10.mf cminch10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch11.mf cminch11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch12.mf cminch12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch14.mf cminch14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch17.mf cminch17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch20.mf cminch20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch25.mf cminch25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch5.mf cminch5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch6.mf cminch6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch7.mf cminch7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch8.mf cminch8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cminch9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cminch9.mf cminch9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt10.mf cmitt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt11.mf cmitt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt12.mf cmitt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt14.mf cmitt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt17.mf cmitt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt20.mf cmitt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt25.mf cmitt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt5.mf cmitt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt6.mf cmitt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt7.mf cmitt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt8.mf cmitt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmitt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmitt9.mf cmitt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi10.mf cmmi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi11.mf cmmi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi12.mf cmmi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi14.mf cmmi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi17.mf cmmi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi20.mf cmmi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi25.mf cmmi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi5.mf cmmi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi6.mf cmmi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi7.mf cmmi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi8.mf cmmi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmi9.mf cmmi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib10.mf cmmib10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib11.mf cmmib11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib12.mf cmmib12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib14.mf cmmib14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib17.mf cmmib17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib20.mf cmmib20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib25.mf cmmib25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib5.mf cmmib5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib6.mf cmmib6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib7.mf cmmib7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib8.mf cmmib8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmmib9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmmib9.mf cmmib9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr10.mf cmr10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr11.mf cmr11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr12.mf cmr12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr14.mf cmr14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr17.mf cmr17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr20.mf cmr20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr25.mf cmr25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr5.mf cmr5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr6.mf cmr6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr7.mf cmr7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr8.mf cmr8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmr9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmr9.mf cmr9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz10.mf cmrcz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz11.mf cmrcz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz12.mf cmrcz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz14.mf cmrcz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz17.mf cmrcz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz20.mf cmrcz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz25.mf cmrcz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz5.mf cmrcz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz6.mf cmrcz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz7.mf cmrcz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz8.mf cmrcz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrcz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrcz9.mf cmrcz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz10.mf cmrisz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz11.mf cmrisz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz12.mf cmrisz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz14.mf cmrisz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz17.mf cmrisz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz20.mf cmrisz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz25.mf cmrisz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz5.mf cmrisz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz6.mf cmrisz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz7.mf cmrisz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz8.mf cmrisz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrisz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrisz9.mf cmrisz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz10.mf cmritz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz11.mf cmritz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz12.mf cmritz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz14.mf cmritz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz17.mf cmritz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz20.mf cmritz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz25.mf cmritz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz5.mf cmritz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz6.mf cmritz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz7.mf cmritz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz8.mf cmritz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmritz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmritz9.mf cmritz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz10.mf cmriz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz11.mf cmriz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz12.mf cmriz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz14.mf cmriz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz17.mf cmriz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz20.mf cmriz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz25.mf cmriz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz5.mf cmriz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz6.mf cmriz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz7.mf cmriz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz8.mf cmriz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmriz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmriz9.mf cmriz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz10.mf cmrotz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz11.mf cmrotz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz12.mf cmrotz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz14.mf cmrotz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz17.mf cmrotz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz20.mf cmrotz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz25.mf cmrotz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz5.mf cmrotz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz6.mf cmrotz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz7.mf cmrotz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz8.mf cmrotz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrotz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrotz9.mf cmrotz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz10.mf cmroz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz11.mf cmroz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz12.mf cmroz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz14.mf cmroz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz17.mf cmroz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz20.mf cmroz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz25.mf cmroz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz5.mf cmroz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz6.mf cmroz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz7.mf cmroz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz8.mf cmroz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmroz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmroz9.mf cmroz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz10.mf cmrsz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz11.mf cmrsz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz12.mf cmrsz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz14.mf cmrsz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz17.mf cmrsz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz20.mf cmrsz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz25.mf cmrsz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz5.mf cmrsz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz6.mf cmrsz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz7.mf cmrsz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz8.mf cmrsz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrsz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrsz9.mf cmrsz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz10.mf cmrtz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz11.mf cmrtz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz12.mf cmrtz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz14.mf cmrtz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz17.mf cmrtz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz20.mf cmrtz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz25.mf cmrtz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz5.mf cmrtz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz6.mf cmrtz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz7.mf cmrtz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz8.mf cmrtz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrtz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrtz9.mf cmrtz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz10.mf cmruz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz11.mf cmruz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz12.mf cmruz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz14.mf cmruz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz17.mf cmruz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz20.mf cmruz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz25.mf cmruz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz5.mf cmruz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz6.mf cmruz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz7.mf cmruz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz8.mf cmruz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmruz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmruz9.mf cmruz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz10.mf cmrz10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz11.mf cmrz11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz12.mf cmrz12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz14.mf cmrz14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz17.mf cmrz17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz20.mf cmrz20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz25.mf cmrz25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz5.mf cmrz5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz6.mf cmrz6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz7.mf cmrz7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz8.mf cmrz8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmrz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmrz9.mf cmrz9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl10.mf cmsl10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl11.mf cmsl11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl12.mf cmsl12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl14.mf cmsl14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl17.mf cmsl17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl20.mf cmsl20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl25.mf cmsl25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl5.mf cmsl5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl6.mf cmsl6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl7.mf cmsl7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl8.mf cmsl8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsl9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsl9.mf cmsl9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt10.mf cmsltt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt11.mf cmsltt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt12.mf cmsltt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt14.mf cmsltt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt17.mf cmsltt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt20.mf cmsltt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt25.mf cmsltt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt5.mf cmsltt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt6.mf cmsltt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt7.mf cmsltt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt8.mf cmsltt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsltt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsltt9.mf cmsltt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss10.mf cmss10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss11.mf cmss11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss12.mf cmss12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss14.mf cmss14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss17.mf cmss17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss20.mf cmss20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss25.mf cmss25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss5.mf cmss5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss6.mf cmss6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss7.mf cmss7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss8.mf cmss8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmss9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmss9.mf cmss9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx10.mf cmssbx10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx11.mf cmssbx11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx12.mf cmssbx12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx14.mf cmssbx14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx17.mf cmssbx17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx20.mf cmssbx20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx25.mf cmssbx25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx5.mf cmssbx5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx6.mf cmssbx6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx7.mf cmssbx7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx8.mf cmssbx8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssbx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssbx9.mf cmssbx9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc10.mf cmssdc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc11.mf cmssdc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc12.mf cmssdc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc14.mf cmssdc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc17.mf cmssdc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc20.mf cmssdc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc25.mf cmssdc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc5.mf cmssdc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc6.mf cmssdc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc7.mf cmssdc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc8.mf cmssdc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssdc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssdc9.mf cmssdc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi10.mf cmssi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi11.mf cmssi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi12.mf cmssi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi14.mf cmssi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi17.mf cmssi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi20.mf cmssi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi25.mf cmssi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi5.mf cmssi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi6.mf cmssi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi7.mf cmssi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi8.mf cmssi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssi9.mf cmssi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq10.mf cmssq10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq11.mf cmssq11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq12.mf cmssq12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq14.mf cmssq14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq17.mf cmssq17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq20.mf cmssq20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq25.mf cmssq25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq5.mf cmssq5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq6.mf cmssq6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq7.mf cmssq7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq8.mf cmssq8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssq9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssq9.mf cmssq9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi10.mf cmssqi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi11.mf cmssqi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi12.mf cmssqi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi14.mf cmssqi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi17.mf cmssqi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi20.mf cmssqi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi25.mf cmssqi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi5.mf cmssqi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi6.mf cmssqi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi7.mf cmssqi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi8.mf cmssqi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssqi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssqi9.mf cmssqi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi10.mf cmssxi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi11.mf cmssxi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi12.mf cmssxi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi14.mf cmssxi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi17.mf cmssxi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi20.mf cmssxi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi25.mf cmssxi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi5.mf cmssxi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi6.mf cmssxi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi7.mf cmssxi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi8.mf cmssxi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmssxi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmssxi9.mf cmssxi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy10.mf cmsy10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy11.mf cmsy11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy12.mf cmsy12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy14.mf cmsy14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy17.mf cmsy17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy20.mf cmsy20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy25.mf cmsy25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy5.mf cmsy5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy6.mf cmsy6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy7.mf cmsy7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy8.mf cmsy8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmsy9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmsy9.mf cmsy9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc10.mf cmtcsc10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc11.mf cmtcsc11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc12.mf cmtcsc12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc14.mf cmtcsc14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc17.mf cmtcsc17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc20.mf cmtcsc20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc25.mf cmtcsc25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc5.mf cmtcsc5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc6.mf cmtcsc6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc7.mf cmtcsc7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc8.mf cmtcsc8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtcsc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtcsc9.mf cmtcsc9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex10.mf cmtex10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex11.mf cmtex11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex12.mf cmtex12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex14.mf cmtex14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex17.mf cmtex17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex20.mf cmtex20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex25.mf cmtex25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex5.mf cmtex5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex6.mf cmtex6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex7.mf cmtex7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex8.mf cmtex8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtex9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtex9.mf cmtex9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti10.mf cmti10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti11.mf cmti11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti12.mf cmti12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti14.mf cmti14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti17.mf cmti17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti20.mf cmti20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti25.mf cmti25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti5.mf cmti5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti6.mf cmti6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti7.mf cmti7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti8.mf cmti8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmti9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmti9.mf cmti9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt10.mf cmtt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt11.mf cmtt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt12.mf cmtt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt14.mf cmtt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt17.mf cmtt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt20.mf cmtt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt25.mf cmtt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt5.mf cmtt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt6.mf cmtt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt7.mf cmtt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt8.mf cmtt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmtt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmtt9.mf cmtt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu10.mf cmu10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu11.mf cmu11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu12.mf cmu12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu14.mf cmu14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu17.mf cmu17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu20.mf cmu20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu25.mf cmu25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu5.mf cmu5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu6.mf cmu6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu7.mf cmu7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu8.mf cmu8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmu9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmu9.mf cmu9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt10.mf cmvtt10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt11.mf cmvtt11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt12.mf cmvtt12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt14.mf cmvtt14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt17.mf cmvtt17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt20.mf cmvtt20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt25.mf cmvtt25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt5.mf cmvtt5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt6.mf cmvtt6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt7.mf cmvtt7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt8.mf cmvtt8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf cmvtt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/cmvtt9.mf cmvtt9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch10.mf czinch10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch11.mf czinch11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch12.mf czinch12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch14.mf czinch14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch17.mf czinch17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch20.mf czinch20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch25.mf czinch25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch5.mf czinch5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch6.mf czinch6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch7.mf czinch7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch8.mf czinch8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czinch9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czinch9.mf czinch9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq10.mf czssq10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq11.mf czssq11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq12.mf czssq12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq14.mf czssq14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq17.mf czssq17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq20.mf czssq20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq25.mf czssq25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq5.mf czssq5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq6.mf czssq6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq7.mf czssq7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq8.mf czssq8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssq9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssq9.mf czssq9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi10.mf czssqi10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi11.mf czssqi11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi12.mf czssqi12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi14.mf czssqi14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi17.mf czssqi17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi20.mf czssqi20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi25.mf czssqi25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi5.mf czssqi5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi6.mf czssqi6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi7.mf czssqi7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi8.mf czssqi8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf czssqi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/czssqi9.mf czssqi9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf fonts )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/fonts fonts )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy10.mf lasy10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy11.mf lasy11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy12.mf lasy12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy14.mf lasy14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy17.mf lasy17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy20.mf lasy20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy25.mf lasy25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy5.mf lasy5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy6.mf lasy6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy7.mf lasy7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy8.mf lasy8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasy9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasy9.mf lasy9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb10.mf lasyb10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb11.mf lasyb11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb12.mf lasyb12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb14.mf lasyb14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb17.mf lasyb17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb20.mf lasyb20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb25.mf lasyb25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb5.mf lasyb5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb6.mf lasyb6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb7.mf lasyb7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb8.mf lasyb8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lasyb9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lasyb9.mf lasyb9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle10.mf lcircle10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle11.mf lcircle11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle12.mf lcircle12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle14.mf lcircle14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle17.mf lcircle17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle20.mf lcircle20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle25.mf lcircle25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle5.mf lcircle5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle6.mf lcircle6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle7.mf lcircle7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle8.mf lcircle8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcircle9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcircle9.mf lcircle9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew10.mf lcirclew10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew11.mf lcirclew11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew12.mf lcirclew12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew14.mf lcirclew14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew17.mf lcirclew17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew20.mf lcirclew20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew25.mf lcirclew25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew5.mf lcirclew5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew6.mf lcirclew6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew7.mf lcirclew7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew8.mf lcirclew8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf lcirclew9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/lcirclew9.mf lcirclew9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line10.mf line10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line11.mf line11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line12.mf line12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line14.mf line14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line17.mf line17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line20.mf line20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line25.mf line25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line5.mf line5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line6.mf line6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line7.mf line7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line8.mf line8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf line9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/line9.mf line9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew10.mf linew10.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew11.mf linew11.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew12.mf linew12.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew14.mf linew14.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew17.mf linew17.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew20.mf linew20.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew25.mf linew25.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew5.mf linew5.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew6.mf linew6.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew7.mf linew7.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew8.mf linew8.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; rm -rf linew9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/src/linew9.mf linew9.mf )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb10.tfm cmb10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb11.tfm cmb11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb12.tfm cmb12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb14.tfm cmb14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb17.tfm cmb17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb20.tfm cmb20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb25.tfm cmb25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb5.tfm cmb5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb6.tfm cmb6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb7.tfm cmb7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb8.tfm cmb8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmb9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmb9.tfm cmb9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx10.tfm cmbizx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx11.tfm cmbizx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx12.tfm cmbizx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx14.tfm cmbizx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx17.tfm cmbizx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx20.tfm cmbizx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx25.tfm cmbizx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx5.tfm cmbizx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx6.tfm cmbizx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx7.tfm cmbizx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx8.tfm cmbizx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbizx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbizx9.tfm cmbizx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx10.tfm cmbozx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx11.tfm cmbozx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx12.tfm cmbozx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx14.tfm cmbozx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx17.tfm cmbozx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx20.tfm cmbozx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx25.tfm cmbozx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx5.tfm cmbozx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx6.tfm cmbozx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx7.tfm cmbozx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx8.tfm cmbozx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbozx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbozx9.tfm cmbozx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy10.tfm cmbsy10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy11.tfm cmbsy11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy12.tfm cmbsy12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy14.tfm cmbsy14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy17.tfm cmbsy17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy20.tfm cmbsy20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy25.tfm cmbsy25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy5.tfm cmbsy5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy6.tfm cmbsy6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy7.tfm cmbsy7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy8.tfm cmbsy8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbsy9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbsy9.tfm cmbsy9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx10.tfm cmbszx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx11.tfm cmbszx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx12.tfm cmbszx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx14.tfm cmbszx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx17.tfm cmbszx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx20.tfm cmbszx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx25.tfm cmbszx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx5.tfm cmbszx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx6.tfm cmbszx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx7.tfm cmbszx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx8.tfm cmbszx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbszx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbszx9.tfm cmbszx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx10.tfm cmbx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx11.tfm cmbx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx12.tfm cmbx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx14.tfm cmbx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx17.tfm cmbx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx20.tfm cmbx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx25.tfm cmbx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx5.tfm cmbx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx6.tfm cmbx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx7.tfm cmbx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx8.tfm cmbx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbx9.tfm cmbx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl10.tfm cmbxsl10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl11.tfm cmbxsl11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl12.tfm cmbxsl12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl14.tfm cmbxsl14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl17.tfm cmbxsl17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl20.tfm cmbxsl20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl25.tfm cmbxsl25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl5.tfm cmbxsl5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl6.tfm cmbxsl6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl7.tfm cmbxsl7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl8.tfm cmbxsl8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxsl9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxsl9.tfm cmbxsl9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti10.tfm cmbxti10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti11.tfm cmbxti11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti12.tfm cmbxti12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti14.tfm cmbxti14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti17.tfm cmbxti17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti20.tfm cmbxti20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti25.tfm cmbxti25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti5.tfm cmbxti5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti6.tfm cmbxti6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti7.tfm cmbxti7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti8.tfm cmbxti8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbxti9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbxti9.tfm cmbxti9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz10.tfm cmbz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz11.tfm cmbz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz12.tfm cmbz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz14.tfm cmbz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz17.tfm cmbz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz20.tfm cmbz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz25.tfm cmbz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz5.tfm cmbz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz6.tfm cmbz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz7.tfm cmbz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz8.tfm cmbz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbz9.tfm cmbz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx10.tfm cmbzx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx11.tfm cmbzx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx12.tfm cmbzx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx14.tfm cmbzx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx17.tfm cmbzx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx20.tfm cmbzx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx25.tfm cmbzx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx5.tfm cmbzx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx6.tfm cmbzx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx7.tfm cmbzx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx8.tfm cmbzx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmbzx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmbzx9.tfm cmbzx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc10.tfm cmcsc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc11.tfm cmcsc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc12.tfm cmcsc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc14.tfm cmcsc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc17.tfm cmcsc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc20.tfm cmcsc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc25.tfm cmcsc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc5.tfm cmcsc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc6.tfm cmcsc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc7.tfm cmcsc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc8.tfm cmcsc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmcsc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmcsc9.tfm cmcsc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc10.tfm cmdszc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc11.tfm cmdszc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc12.tfm cmdszc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc14.tfm cmdszc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc17.tfm cmdszc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc20.tfm cmdszc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc25.tfm cmdszc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc5.tfm cmdszc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc6.tfm cmdszc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc7.tfm cmdszc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc8.tfm cmdszc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdszc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdszc9.tfm cmdszc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh10.tfm cmdunh10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh11.tfm cmdunh11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh12.tfm cmdunh12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh14.tfm cmdunh14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh17.tfm cmdunh17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh20.tfm cmdunh20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh25.tfm cmdunh25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh5.tfm cmdunh5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh6.tfm cmdunh6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh7.tfm cmdunh7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh8.tfm cmdunh8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmdunh9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmdunh9.tfm cmdunh9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex10.tfm cmex10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex11.tfm cmex11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex12.tfm cmex12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex14.tfm cmex14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex17.tfm cmex17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex20.tfm cmex20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex25.tfm cmex25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex5.tfm cmex5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex6.tfm cmex6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex7.tfm cmex7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex8.tfm cmex8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmex9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmex9.tfm cmex9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff10.tfm cmff10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff11.tfm cmff11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff12.tfm cmff12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff14.tfm cmff14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff17.tfm cmff17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff20.tfm cmff20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff25.tfm cmff25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff5.tfm cmff5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff6.tfm cmff6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff7.tfm cmff7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff8.tfm cmff8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmff9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmff9.tfm cmff9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi10.tfm cmfi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi11.tfm cmfi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi12.tfm cmfi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi14.tfm cmfi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi17.tfm cmfi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi20.tfm cmfi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi25.tfm cmfi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi5.tfm cmfi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi6.tfm cmfi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi7.tfm cmfi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi8.tfm cmfi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmfi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmfi9.tfm cmfi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch10.tfm cminch10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch11.tfm cminch11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch12.tfm cminch12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch14.tfm cminch14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch17.tfm cminch17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch20.tfm cminch20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch25.tfm cminch25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch5.tfm cminch5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch6.tfm cminch6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch7.tfm cminch7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch8.tfm cminch8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cminch9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cminch9.tfm cminch9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt10.tfm cmitt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt11.tfm cmitt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt12.tfm cmitt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt14.tfm cmitt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt17.tfm cmitt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt20.tfm cmitt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt25.tfm cmitt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt5.tfm cmitt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt6.tfm cmitt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt7.tfm cmitt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt8.tfm cmitt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmitt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmitt9.tfm cmitt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi10.tfm cmmi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi11.tfm cmmi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi12.tfm cmmi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi14.tfm cmmi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi17.tfm cmmi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi20.tfm cmmi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi25.tfm cmmi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi5.tfm cmmi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi6.tfm cmmi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi7.tfm cmmi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi8.tfm cmmi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmi9.tfm cmmi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib10.tfm cmmib10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib11.tfm cmmib11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib12.tfm cmmib12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib14.tfm cmmib14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib17.tfm cmmib17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib20.tfm cmmib20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib25.tfm cmmib25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib5.tfm cmmib5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib6.tfm cmmib6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib7.tfm cmmib7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib8.tfm cmmib8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmmib9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmmib9.tfm cmmib9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr10.tfm cmr10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr11.tfm cmr11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr12.tfm cmr12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr14.tfm cmr14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr17.tfm cmr17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr20.tfm cmr20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr25.tfm cmr25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr5.tfm cmr5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr6.tfm cmr6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr7.tfm cmr7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr8.tfm cmr8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmr9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmr9.tfm cmr9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz10.tfm cmrcz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz11.tfm cmrcz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz12.tfm cmrcz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz14.tfm cmrcz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz17.tfm cmrcz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz20.tfm cmrcz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz25.tfm cmrcz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz5.tfm cmrcz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz6.tfm cmrcz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz7.tfm cmrcz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz8.tfm cmrcz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrcz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrcz9.tfm cmrcz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz10.tfm cmrisz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz11.tfm cmrisz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz12.tfm cmrisz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz14.tfm cmrisz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz17.tfm cmrisz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz20.tfm cmrisz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz25.tfm cmrisz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz5.tfm cmrisz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz6.tfm cmrisz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz7.tfm cmrisz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz8.tfm cmrisz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrisz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrisz9.tfm cmrisz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz10.tfm cmritz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz11.tfm cmritz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz12.tfm cmritz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz14.tfm cmritz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz17.tfm cmritz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz20.tfm cmritz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz25.tfm cmritz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz5.tfm cmritz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz6.tfm cmritz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz7.tfm cmritz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz8.tfm cmritz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmritz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmritz9.tfm cmritz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz10.tfm cmriz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz11.tfm cmriz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz12.tfm cmriz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz14.tfm cmriz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz17.tfm cmriz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz20.tfm cmriz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz25.tfm cmriz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz5.tfm cmriz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz6.tfm cmriz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz7.tfm cmriz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz8.tfm cmriz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmriz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmriz9.tfm cmriz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz10.tfm cmrotz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz11.tfm cmrotz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz12.tfm cmrotz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz14.tfm cmrotz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz17.tfm cmrotz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz20.tfm cmrotz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz25.tfm cmrotz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz5.tfm cmrotz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz6.tfm cmrotz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz7.tfm cmrotz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz8.tfm cmrotz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrotz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrotz9.tfm cmrotz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz10.tfm cmroz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz11.tfm cmroz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz12.tfm cmroz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz14.tfm cmroz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz17.tfm cmroz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz20.tfm cmroz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz25.tfm cmroz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz5.tfm cmroz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz6.tfm cmroz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz7.tfm cmroz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz8.tfm cmroz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmroz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmroz9.tfm cmroz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz10.tfm cmrsz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz11.tfm cmrsz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz12.tfm cmrsz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz14.tfm cmrsz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz17.tfm cmrsz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz20.tfm cmrsz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz25.tfm cmrsz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz5.tfm cmrsz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz6.tfm cmrsz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz7.tfm cmrsz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz8.tfm cmrsz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrsz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrsz9.tfm cmrsz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz10.tfm cmrtz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz11.tfm cmrtz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz12.tfm cmrtz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz14.tfm cmrtz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz17.tfm cmrtz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz20.tfm cmrtz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz25.tfm cmrtz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz5.tfm cmrtz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz6.tfm cmrtz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz7.tfm cmrtz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz8.tfm cmrtz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrtz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrtz9.tfm cmrtz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz10.tfm cmruz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz11.tfm cmruz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz12.tfm cmruz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz14.tfm cmruz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz17.tfm cmruz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz20.tfm cmruz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz25.tfm cmruz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz5.tfm cmruz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz6.tfm cmruz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz7.tfm cmruz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz8.tfm cmruz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmruz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmruz9.tfm cmruz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz10.tfm cmrz10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz11.tfm cmrz11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz12.tfm cmrz12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz14.tfm cmrz14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz17.tfm cmrz17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz20.tfm cmrz20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz25.tfm cmrz25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz5.tfm cmrz5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz6.tfm cmrz6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz7.tfm cmrz7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz8.tfm cmrz8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmrz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmrz9.tfm cmrz9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl10.tfm cmsl10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl11.tfm cmsl11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl12.tfm cmsl12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl14.tfm cmsl14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl17.tfm cmsl17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl20.tfm cmsl20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl25.tfm cmsl25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl5.tfm cmsl5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl6.tfm cmsl6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl7.tfm cmsl7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl8.tfm cmsl8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsl9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsl9.tfm cmsl9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt10.tfm cmsltt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt11.tfm cmsltt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt12.tfm cmsltt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt14.tfm cmsltt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt17.tfm cmsltt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt20.tfm cmsltt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt25.tfm cmsltt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt5.tfm cmsltt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt6.tfm cmsltt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt7.tfm cmsltt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt8.tfm cmsltt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsltt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsltt9.tfm cmsltt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss10.tfm cmss10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss11.tfm cmss11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss12.tfm cmss12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss14.tfm cmss14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss17.tfm cmss17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss20.tfm cmss20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss25.tfm cmss25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss5.tfm cmss5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss6.tfm cmss6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss7.tfm cmss7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss8.tfm cmss8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmss9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmss9.tfm cmss9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx10.tfm cmssbx10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx11.tfm cmssbx11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx12.tfm cmssbx12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx14.tfm cmssbx14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx17.tfm cmssbx17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx20.tfm cmssbx20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx25.tfm cmssbx25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx5.tfm cmssbx5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx6.tfm cmssbx6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx7.tfm cmssbx7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx8.tfm cmssbx8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssbx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssbx9.tfm cmssbx9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc10.tfm cmssdc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc11.tfm cmssdc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc12.tfm cmssdc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc14.tfm cmssdc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc17.tfm cmssdc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc20.tfm cmssdc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc25.tfm cmssdc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc5.tfm cmssdc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc6.tfm cmssdc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc7.tfm cmssdc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc8.tfm cmssdc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssdc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssdc9.tfm cmssdc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi10.tfm cmssi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi11.tfm cmssi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi12.tfm cmssi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi14.tfm cmssi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi17.tfm cmssi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi20.tfm cmssi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi25.tfm cmssi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi5.tfm cmssi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi6.tfm cmssi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi7.tfm cmssi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi8.tfm cmssi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssi9.tfm cmssi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq10.tfm cmssq10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq11.tfm cmssq11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq12.tfm cmssq12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq14.tfm cmssq14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq17.tfm cmssq17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq20.tfm cmssq20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq25.tfm cmssq25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq5.tfm cmssq5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq6.tfm cmssq6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq7.tfm cmssq7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq8.tfm cmssq8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssq9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssq9.tfm cmssq9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi10.tfm cmssqi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi11.tfm cmssqi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi12.tfm cmssqi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi14.tfm cmssqi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi17.tfm cmssqi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi20.tfm cmssqi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi25.tfm cmssqi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi5.tfm cmssqi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi6.tfm cmssqi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi7.tfm cmssqi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi8.tfm cmssqi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssqi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssqi9.tfm cmssqi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi10.tfm cmssxi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi11.tfm cmssxi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi12.tfm cmssxi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi14.tfm cmssxi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi17.tfm cmssxi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi20.tfm cmssxi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi25.tfm cmssxi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi5.tfm cmssxi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi6.tfm cmssxi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi7.tfm cmssxi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi8.tfm cmssxi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmssxi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmssxi9.tfm cmssxi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy10.tfm cmsy10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy11.tfm cmsy11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy12.tfm cmsy12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy14.tfm cmsy14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy17.tfm cmsy17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy20.tfm cmsy20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy25.tfm cmsy25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy5.tfm cmsy5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy6.tfm cmsy6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy7.tfm cmsy7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy8.tfm cmsy8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmsy9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmsy9.tfm cmsy9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc10.tfm cmtcsc10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc11.tfm cmtcsc11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc12.tfm cmtcsc12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc14.tfm cmtcsc14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc17.tfm cmtcsc17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc20.tfm cmtcsc20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc25.tfm cmtcsc25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc5.tfm cmtcsc5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc6.tfm cmtcsc6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc7.tfm cmtcsc7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc8.tfm cmtcsc8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtcsc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtcsc9.tfm cmtcsc9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex10.tfm cmtex10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex11.tfm cmtex11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex12.tfm cmtex12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex14.tfm cmtex14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex17.tfm cmtex17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex20.tfm cmtex20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex25.tfm cmtex25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex5.tfm cmtex5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex6.tfm cmtex6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex7.tfm cmtex7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex8.tfm cmtex8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtex9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtex9.tfm cmtex9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti10.tfm cmti10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti11.tfm cmti11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti12.tfm cmti12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti14.tfm cmti14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti17.tfm cmti17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti20.tfm cmti20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti25.tfm cmti25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti5.tfm cmti5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti6.tfm cmti6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti7.tfm cmti7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti8.tfm cmti8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmti9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmti9.tfm cmti9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt10.tfm cmtt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt11.tfm cmtt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt12.tfm cmtt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt14.tfm cmtt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt17.tfm cmtt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt20.tfm cmtt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt25.tfm cmtt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt5.tfm cmtt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt6.tfm cmtt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt7.tfm cmtt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt8.tfm cmtt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmtt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmtt9.tfm cmtt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu10.tfm cmu10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu11.tfm cmu11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu12.tfm cmu12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu14.tfm cmu14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu17.tfm cmu17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu20.tfm cmu20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu25.tfm cmu25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu5.tfm cmu5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu6.tfm cmu6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu7.tfm cmu7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu8.tfm cmu8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmu9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmu9.tfm cmu9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt10.tfm cmvtt10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt11.tfm cmvtt11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt12.tfm cmvtt12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt14.tfm cmvtt14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt17.tfm cmvtt17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt20.tfm cmvtt20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt25.tfm cmvtt25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt5.tfm cmvtt5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt6.tfm cmvtt6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt7.tfm cmvtt7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt8.tfm cmvtt8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf cmvtt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/cmvtt9.tfm cmvtt9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch10.tfm czinch10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch11.tfm czinch11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch12.tfm czinch12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch14.tfm czinch14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch17.tfm czinch17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch20.tfm czinch20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch25.tfm czinch25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch5.tfm czinch5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch6.tfm czinch6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch7.tfm czinch7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch8.tfm czinch8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czinch9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czinch9.tfm czinch9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq10.tfm czssq10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq11.tfm czssq11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq12.tfm czssq12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq14.tfm czssq14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq17.tfm czssq17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq20.tfm czssq20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq25.tfm czssq25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq5.tfm czssq5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq6.tfm czssq6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq7.tfm czssq7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq8.tfm czssq8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssq9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssq9.tfm czssq9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi10.tfm czssqi10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi11.tfm czssqi11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi12.tfm czssqi12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi14.tfm czssqi14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi17.tfm czssqi17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi20.tfm czssqi20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi25.tfm czssqi25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi5.tfm czssqi5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi6.tfm czssqi6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi7.tfm czssqi7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi8.tfm czssqi8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf czssqi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/czssqi9.tfm czssqi9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy10.tfm lasy10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy11.tfm lasy11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy12.tfm lasy12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy14.tfm lasy14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy17.tfm lasy17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy20.tfm lasy20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy25.tfm lasy25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy5.tfm lasy5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy6.tfm lasy6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy7.tfm lasy7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy8.tfm lasy8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasy9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasy9.tfm lasy9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb10.tfm lasyb10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb11.tfm lasyb11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb12.tfm lasyb12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb14.tfm lasyb14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb17.tfm lasyb17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb20.tfm lasyb20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb25.tfm lasyb25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb5.tfm lasyb5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb6.tfm lasyb6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb7.tfm lasyb7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb8.tfm lasyb8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lasyb9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lasyb9.tfm lasyb9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle10.tfm lcircle10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle11.tfm lcircle11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle12.tfm lcircle12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle14.tfm lcircle14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle17.tfm lcircle17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle20.tfm lcircle20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle25.tfm lcircle25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle5.tfm lcircle5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle6.tfm lcircle6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle7.tfm lcircle7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle8.tfm lcircle8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcircle9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcircle9.tfm lcircle9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew10.tfm lcirclew10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew11.tfm lcirclew11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew12.tfm lcirclew12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew14.tfm lcirclew14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew17.tfm lcirclew17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew20.tfm lcirclew20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew25.tfm lcirclew25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew5.tfm lcirclew5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew6.tfm lcirclew6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew7.tfm lcirclew7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew8.tfm lcirclew8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf lcirclew9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/lcirclew9.tfm lcirclew9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line10.tfm line10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line11.tfm line11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line12.tfm line12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line14.tfm line14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line17.tfm line17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line20.tfm line20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line25.tfm line25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line5.tfm line5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line6.tfm line6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line7.tfm line7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line8.tfm line8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf line9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/line9.tfm line9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew10.tfm linew10.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew11.tfm linew11.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew12.tfm linew12.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew14.tfm linew14.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew17.tfm linew17.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew20.tfm linew20.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew25.tfm linew25.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew5.tfm linew5.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew6.tfm linew6.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew7.tfm linew7.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew8.tfm linew8.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; rm -rf linew9.tfm )
( cd usr/lib/texmf/fonts/cm/sauter/tfm ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/sauter/tfm/linew9.tfm linew9.tfm )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf accent.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/accent.mf accent.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf bigacc.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/bigacc.mf bigacc.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf bigdel.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/bigdel.mf bigdel.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf bigop.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/bigop.mf bigop.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf calu.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/calu.mf calu.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf cmbase.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/cmbase.mf cmbase.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf comlig.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/comlig.mf comlig.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf csc.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/csc.mf csc.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf cscspu.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/cscspu.mf cscspu.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf greekl.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/greekl.mf greekl.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf greeku.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/greeku.mf greeku.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf itald.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/itald.mf itald.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf italig.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/italig.mf italig.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf itall.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/itall.mf itall.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf italms.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/italms.mf italms.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf italp.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/italp.mf italp.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf italsp.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/italsp.mf italsp.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf mathex.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/mathex.mf mathex.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf mathit.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/mathit.mf mathit.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf mathsy.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/mathsy.mf mathsy.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf olddig.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/olddig.mf olddig.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf punct.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/punct.mf punct.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf roman.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/roman.mf roman.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romand.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romand.mf romand.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romanl.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romanl.mf romanl.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romanp.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romanp.mf romanp.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romanu.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romanu.mf romanu.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romlig.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romlig.mf romlig.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romms.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romms.mf romms.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romspl.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romspl.mf romspl.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romspu.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romspu.mf romspu.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf romsub.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/romsub.mf romsub.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf sym.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/sym.mf sym.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf symbol.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/symbol.mf symbol.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf texset.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/texset.mf texset.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf textit.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/textit.mf textit.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf title.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/title.mf title.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf tset.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/tset.mf tset.mf )
( cd usr/lib/texmf/fonts/cm/src ; rm -rf tsetsl.mf )
( cd usr/lib/texmf/fonts/cm/src ; ln -sf /cdrom/live/usr/lib/texmf/fonts/cm/src/tsetsl.mf tsetsl.mf )
